==> dokuwiki_0.0.20061106.orig.tar.gz: dokuwiki-2006-11-06/inc/lang/sr/lang.php <==
<?php
/**
 * serbian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Filip Brcic <brcha@users.sourceforge.net>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Изнеми ову страницу';
$lang['btn_source'] = 'Прикажи изворни код';
$lang['btn_show']   = 'Прикажи страницу';
$lang['btn_create'] = 'Направи ову страницу';
$lang['btn_search'] = 'Тражи';
$lang['btn_save']   = 'Сачувај';
$lang['btn_preview']= 'Прегледај';
$lang['btn_top']    = 'Врати се на врх';
$lang['btn_newer']  = '<< новије';
$lang['btn_older']  = 'старије >>';
$lang['btn_revs']   = 'Старе верзије';
$lang['btn_recent'] = 'Скорије измене';
$lang['btn_upload'] = 'Пошаљи';
$lang['btn_cancel'] = 'Поништи';
$lang['btn_index']  = 'Индекс';
$lang['btn_secedit']= 'Измени';
$lang['btn_login']  = 'Пријави се';
$lang['btn_logout'] = 'Одјави се';
$lang['btn_admin']  = 'Администрација';
$lang['btn_update'] = 'Ажурирај';
$lang['btn_delete'] = 'Избриши';
$lang['btn_back']   = 'Натраг';
$lang['btn_backlink']    = "Повратне везе";
$lang['btn_backtomedia'] = 'Врати се на избор медијског фајла';
$lang['btn_subscribe']   = 'Пријави се на измене';
$lang['btn_unsubscribe'] = 'Одјави се са измена';

$lang['loggedinas'] = 'Пријављен као';
$lang['user']       = 'Корисничко име';
$lang['pass']       = 'Шифра';
$lang['passchk']    = 'поново';
$lang['remember']   = 'Запамти ме';
$lang['fullname']   = 'Пуно име';
$lang['email']      = 'Е-адреса';
$lang['register']   = 'Региструј се';
$lang['badlogin']   = 'Извините, није добро корисничко име или шифра.';

$lang['regmissing'] = 'Извините, морате да попуните сва поља.';
$lang['reguexists'] = 'Извините, корисник са истим именом већ постоји.';
$lang['regsuccess'] = 'Корисник је направљен и шифра је послата путем е-поште.';
$lang['regsuccess2']= 'Корисник је направљен.';
$lang['regmailfail']= 'Изгледа да је дошло до грешке приликом слања шифре е-поштом. Молим Вас, контактирајте администратора!';
$lang['regbadmail'] = 'Дата е-адреса није у реду - ако мислите да је ово грешка, контактирајте администратора';
$lang['regbadpass'] = 'Две задате шифре нису исте. Молим Вас, пробајте поново.';
$lang['regpwmail']  = 'Ваша DokuWiki шифра';
$lang['reghere']    = 'Још увек немате налог? Само направите један';

$lang['txt_upload']   = 'Изаберите фајл за слање';
$lang['txt_filename'] = 'Унесите вики-име (опционо)';
$lang['txt_overwrt']  = 'Препишите тренутни фајл';
$lang['lockedby']     = 'Тренутно закључано од стране';
$lang['lockexpire']   = 'Закључавање истиче';
$lang['willexpire']   = 'Ваше закључавање за измену ове странице ће да истекне за један минут.\nДа би сте избегли конфликте, искористите дугме за преглед како би сте ресетовали тајмер закључавања.';

$lang['notsavedyet'] = 'Несачуване измене ће бити изгубљене.\nДа ли стварно желите да наставите?';

$lang['rssfailed']   = 'Дошло је до грешке приликом преузимања овог довода: ';
$lang['nothingfound']= 'Ништа није нађено.';

$lang['mediaselect'] = 'Избор медијског фајла';
$lang['fileupload']  = 'Слање медијског фајла';
$lang['uploadsucc']  = 'Успешно слање';
$lang['uploadfail']  = 'Неуспешно слање. Можда немате дозволу?';
$lang['uploadwrong'] = 'Слање је забрањено. Овај наставак фајла је забрањен!';
$lang['uploadexist'] = 'Фајл већ постоји. Ништа није учињено.';
$lang['deletesucc']  = 'Фајл "%s" је избрисан.';
$lang['deletefail']  = '"%s" није могао да буде избрисан - проверите дозволе.';
$lang['mediainuse']  = 'Фајл "%s" није избрисан - још је у употреби.';
$lang['namespaces']  = 'Именски простори';
$lang['mediafiles']  = 'Доступни фајлови у';

$lang['reference']   = 'Референце за';
$lang['ref_inuse']   = 'Фајл не може да буде избрисан јер га још увек користе следеће странице:';
$lang['ref_hidden']  = 'Неке референце су на страницама за које немате дозволе за читање';

$lang['hits']       = 'Поготци';
$lang['quickhits']  = 'Имена страница које се поклапају';
$lang['toc']        = 'Садржај';
$lang['current']    = 'тренутно';
$lang['yours']      = 'Ваша верзија';
$lang['diff']       = 'прикажи разлике до тренутне верзије';
$lang['line']       = 'Линија';
$lang['breadcrumb'] = 'Траг';
$lang['lastmod']    = 'Последњи пут мењано';
$lang['by']         = '';
$lang['deleted']    = 'избрисано';
$lang['created']    = 'направљено';
$lang['restored']   = 'стара верзија повраћена';
$lang['summary']    = 'Сажетак измене';

$lang['mail_newpage'] = 'страница додата:';
$lang['mail_changed'] = 'страница измењена:';

$lang['nosmblinks'] = 'Повезивање са Windows дељеним фолдерима ради само у Мајкрософтовом Интернет Претраживачу.\nИпак, можете да ископирате и залепите везу.';

$lang['qb_alert']   = 'Молим вас, унесите текст који желите да форматизујете.\nБиће додат на крај документа.';
$lang['qb_bold']    = 'Мастан текст';
$lang['qb_italic']  = 'Курзивни текст';
$lang['qb_underl']  = 'Подвучени текст';
$lang['qb_code']    = 'Изворни код';
$lang['qb_strike']  = 'Прецртани текст';
$lang['qb_h1']      = 'Наслов 1. нивоа';
$lang['qb_h2']      = 'Наслов 2. нивоа';
$lang['qb_h3']      = 'Наслов 3. нивоа';
$lang['qb_h4']      = 'Наслов 4. нивоа';
$lang['qb_h5']      = 'Наслов 5. нивоа';
$lang['qb_link']    = 'Унутрашња веза';
$lang['qb_extlink'] = 'Спољашња веза';
$lang['qb_hr']      = 'Хоризонтална линија';
$lang['qb_ol']      = 'Елемент уређене листе';
$lang['qb_ul']      = 'Елемент неуређене листе';
$lang['qb_media']   = 'Додај слике и друге фајлове';
$lang['qb_sig']     = 'Убаци потпис';

$lang['del_confirm']= 'Обриши овај унос?';
$lang['admin_register']= 'Додај новог корисника';

$lang['spell_start'] = 'Провери правопис';
$lang['spell_stop']  = 'Настави са изменама';
$lang['spell_wait']  = 'Молим Вас, сачекајте...';
$lang['spell_noerr'] = 'Нису нађене грешке';
$lang['spell_nosug'] = 'Нема сугестија';
$lang['spell_change']= 'Измени';

$lang['metaedit']    = 'Измени мета-податке';
$lang['metasaveerr'] = 'Записивање мета-података није било успешно';
$lang['metasaveok']  = 'Мета-подаци су сачувани';
$lang['img_backto']  = 'Натраг на';
$lang['img_title']   = 'Наслов';
$lang['img_caption'] = 'Назив';
$lang['img_date']    = 'Датум';
$lang['img_fname']   = 'Име фајла';
$lang['img_fsize']   = 'Величина';
$lang['img_artist']  = 'Фотограф';
$lang['img_copyr']   = 'Права копирања';
$lang['img_format']  = 'Формат';
$lang['img_camera']  = 'Камера';
$lang['img_keywords']= 'Кључне речи';

$lang['subscribe_success']  = 'Додао сам %s на листу претплатника за %s';
$lang['subscribe_error']    = 'Дошло је до грешке при додавању %s на листу претплатника за %s';
$lang['subscribe_noaddress']= 'Не постоји е-адреса асоцирана са Вашим налогом. Не можете да будете додати на листу претплатника';
$lang['unsubscribe_success']= 'Избрисао сам %s са листе претплатника за %s';
$lang['unsubscribe_error']  = 'Дошло је до грешке приликом брисања %s са листе претплатника за %s';

//Setup VIM: ex: et ts=2 enc=utf-8 :

==> dokuwiki_0.0.20070626b.orig.tar.gz: dokuwiki-2007-06-26b/inc/lang/sr/lang.php <==
<?php
/**
 * serbian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Filip Brcic <brcha@users.sourceforge.net>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';
$lang['doublequoteopening']  = '„';//&bdquo;
$lang['doublequoteclosing']  = '“';//&ldquo;
$lang['singlequoteopening']  = '‚';//&sbquo;
$lang['singlequoteclosing']  = '‘';//&lsquo;

$lang['btn_edit']   = 'Изнеми ову страницу';
$lang['btn_source'] = 'Прикажи изворни код';
$lang['btn_show']   = 'Прикажи страницу';
$lang['btn_create'] = 'Направи ову страницу';
$lang['btn_search'] = 'Тражи';
$lang['btn_save']   = 'Сачувај';
$lang['btn_preview']= 'Прегледај';
$lang['btn_top']    = 'Врати се на врх';
$lang['btn_newer']  = '<< новије';
$lang['btn_older']  = 'старије >>';
$lang['btn_revs']   = 'Старе верзије';
$lang['btn_recent'] = 'Скорије измене';
$lang['btn_upload'] = 'Пошаљи';
$lang['btn_cancel'] = 'Поништи';
$lang['btn_index']  = 'Индекс';
$lang['btn_secedit']= 'Измени';
$lang['btn_login']  = 'Пријави се';
$lang['btn_logout'] = 'Одјави се';
$lang['btn_admin']  = 'Администрација';
$lang['btn_update'] = 'Ажурирај';
$lang['btn_delete'] = 'Избриши';
$lang['btn_back']   = 'Натраг';
$lang['btn_backlink']    = "Повратне везе";
$lang['btn_backtomedia'] = 'Врати се на избор медијског фајла';
$lang['btn_subscribe']   = 'Пријави се на измене';
$lang['btn_unsubscribe'] = 'Одјави се са измена';

$lang['loggedinas'] = 'Пријављен као';
$lang['user']       = 'Корисничко име';
$lang['pass']       = 'Шифра';
$lang['passchk']    = 'поново';
$lang['remember']   = 'Запамти ме';
$lang['fullname']   = 'Пуно име';
$lang['email']      = 'Е-адреса';
$lang['register']   = 'Региструј се';
$lang['badlogin']   = 'Извините, није добро корисничко име или шифра.';

$lang['regmissing'] = 'Извините, морате да попуните сва поља.';
$lang['reguexists'] = 'Извините, корисник са истим именом већ постоји.';
$lang['regsuccess'] = 'Корисник је направљен и шифра је послата путем е-поште.';
$lang['regsuccess2']= 'Корисник је направљен.';
$lang['regmailfail']= 'Изгледа да је дошло до грешке приликом слања шифре е-поштом. Молим Вас, контактирајте администратора!';
$lang['regbadmail'] = 'Дата е-адреса није у реду - ако мислите да је ово грешка, контактирајте администратора';
$lang['regbadpass'] = 'Две задате шифре нису исте. Молим Вас, пробајте поново.';
$lang['regpwmail']  = 'Ваша DokuWiki шифра';
$lang['reghere']    = 'Још увек немате налог? Само направите један';

$lang['txt_upload']   = 'Изаберите фајл за слање';
$lang['txt_filename'] = 'Унесите вики-име (опционо)';
$lang['txt_overwrt']  = 'Препишите тренутни фајл';
$lang['lockedby']     = 'Тренутно закључано од стране';
$lang['lockexpire']   = 'Закључавање истиче';
$lang['willexpire']   = 'Ваше закључавање за измену ове странице ће да истекне за један минут.\nДа би сте избегли конфликте, искористите дугме за преглед како би сте ресетовали тајмер закључавања.';

$lang['notsavedyet'] = 'Несачуване измене ће бити изгубљене.\nДа ли стварно желите да наставите?';

$lang['rssfailed']   = 'Дошло је до грешке приликом преузимања овог довода: ';
$lang['nothingfound']= 'Ништа није нађено.';

$lang['mediaselect'] = 'Избор медијског фајла';
$lang['fileupload']  = 'Слање медијског фајла';
$lang['uploadsucc']  = 'Успешно слање';
$lang['uploadfail']  = 'Неуспешно слање. Можда немате дозволу?';
$lang['uploadwrong'] = 'Слање је забрањено. Овај наставак фајла је забрањен!';
$lang['uploadexist'] = 'Фајл већ постоји. Ништа није учињено.';
$lang['deletesucc']  = 'Фајл "%s" је избрисан.';
$lang['deletefail']  = '"%s" није могао да буде избрисан - проверите дозволе.';
$lang['mediainuse']  = 'Фајл "%s" није избрисан - још је у употреби.';
$lang['namespaces']  = 'Именски простори';
$lang['mediafiles']  = 'Доступни фајлови у';

$lang['reference']   = 'Референце за';
$lang['ref_inuse']   = 'Фајл не може да буде избрисан јер га још увек користе следеће странице:';
$lang['ref_hidden']  = 'Неке референце су на страницама за које немате дозволе за читање';

$lang['hits']       = 'Поготци';
$lang['quickhits']  = 'Имена страница које се поклапају';
$lang['toc']        = 'Садржај';
$lang['current']    = 'тренутно';
$lang['yours']      = 'Ваша верзија';
$lang['diff']       = 'прикажи разлике до тренутне верзије';
$lang['line']       = 'Линија';
$lang['breadcrumb'] = 'Траг';
$lang['lastmod']    = 'Последњи пут мењано';
$lang['by']         = '';
$lang['deleted']    = 'избрисано';
$lang['created']    = 'направљено';
$lang['restored']   = 'стара верзија повраћена';
$lang['summary']    = 'Сажетак измене';

$lang['mail_newpage'] = 'страница додата:';
$lang['mail_changed'] = 'страница измењена:';

$lang['nosmblinks'] = 'Повезивање са Windows дељеним фолдерима ради само у Мајкрософтовом Интернет Претраживачу.\nИпак, можете да ископирате и залепите везу.';

$lang['qb_alert']   = 'Молим вас, унесите текст који желите да форматизујете.\nБиће додат на крај документа.';
$lang['qb_bold']    = 'Мастан текст';
$lang['qb_italic']  = 'Курзивни текст';
$lang['qb_underl']  = 'Подвучени текст';
$lang['qb_code']    = 'Изворни код';
$lang['qb_strike']  = 'Прецртани текст';
$lang['qb_h1']      = 'Наслов 1. нивоа';
$lang['qb_h2']      = 'Наслов 2. нивоа';
$lang['qb_h3']      = 'Наслов 3. нивоа';
$lang['qb_h4']      = 'Наслов 4. нивоа';
$lang['qb_h5']      = 'Наслов 5. нивоа';
$lang['qb_link']    = 'Унутрашња веза';
$lang['qb_extlink'] = 'Спољашња веза';
$lang['qb_hr']      = 'Хоризонтална линија';
$lang['qb_ol']      = 'Елемент уређене листе';
$lang['qb_ul']      = 'Елемент неуређене листе';
$lang['qb_media']   = 'Додај слике и друге фајлове';
$lang['qb_sig']     = 'Убаци потпис';

$lang['del_confirm']= 'Обриши овај унос?';
$lang['admin_register']= 'Додај новог корисника';

$lang['spell_start'] = 'Провери правопис';
$lang['spell_stop']  = 'Настави са изменама';
$lang['spell_wait']  = 'Молим Вас, сачекајте...';
$lang['spell_noerr'] = 'Нису нађене грешке';
$lang['spell_nosug'] = 'Нема сугестија';
$lang['spell_change']= 'Измени';

$lang['metaedit']    = 'Измени мета-податке';
$lang['metasaveerr'] = 'Записивање мета-података није било успешно';
$lang['metasaveok']  = 'Мета-подаци су сачувани';
$lang['img_backto']  = 'Натраг на';
$lang['img_title']   = 'Наслов';
$lang['img_caption'] = 'Назив';
$lang['img_date']    = 'Датум';
$lang['img_fname']   = 'Име фајла';
$lang['img_fsize']   = 'Величина';
$lang['img_artist']  = 'Фотограф';
$lang['img_copyr']   = 'Права копирања';
$lang['img_format']  = 'Формат';
$lang['img_camera']  = 'Камера';
$lang['img_keywords']= 'Кључне речи';

$lang['subscribe_success']  = 'Додао сам %s на листу претплатника за %s';
$lang['subscribe_error']    = 'Дошло је до грешке при додавању %s на листу претплатника за %s';
$lang['subscribe_noaddress']= 'Не постоји е-адреса асоцирана са Вашим налогом. Не можете да будете додати на листу претплатника';
$lang['unsubscribe_success']= 'Избрисао сам %s са листе претплатника за %s';
$lang['unsubscribe_error']  = 'Дошло је до грешке приликом брисања %s са листе претплатника за %s';

//Setup VIM: ex: et ts=2 enc=utf-8 :
